@@ -2,7 +2,7 @@
 # Modules
 # ==============================================================================
 # Built-ins
-import os, sys, time, datetime, copy
+import os, sys, time, datetime, copy, warnings
 from collections import OrderedDict, defaultdict
 from tqdm import tqdm
 
@@ -154,6 +154,11 @@ class HierarchicalClassifier(BaseEstimator, ClassifierMixin):
 
     # Save object to file
     def save_model(self, path, compression="infer"):
+        warnings.warn("`save_model` is deprecated and will be removed in future versions.  Please use `to_file` instead.", DeprecationWarning)
+        write_object(self, path, compression=compression)
+
+    # Save object to file
+    def to_file(self, path, compression="infer"):
         write_object(self, path, compression=compression)
 
     # Convert a NetworkX graph object to an ete3 Tree
